{ inputs, pkgs, ... }: {
  imports = [
    inputs.nixos-hardware.nixosModules.chuwi-minibook-x
    ./hardware-configuration.nix
    ./n100.nix
    ../../profiles/base
    ../../profiles/graphical
    ../../profiles/kde
    ../../profiles/home-manager
    ../../users/transcaffeine
    ../../users/leona
  ];

  # Use the systemd-boot EFI boot loader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  boot.kernelPackages = pkgs.linuxPackages_6_13;
  boot.kernelParams = [
   # disable panel self refresh for i915
   #"i915.enable_psr=0"
   # set max cstate to 2 (suspend?)
   # "intel_idle.max_cstate=2"
    "nvme.noacpi=1"
  ];
  hardware.enableRedistributableFirmware = true;

  networking.hostName = "affogato";
  networking.hosts = {
    "78.94.116.221" = [
      "git.finally.coffee"
      "chat.finallycoffee.eu"
      "matrix.finallycoffee.eu"
      "cloud.finallycoffee.eu"
    ];
  };
  networking.firewall = {
    enable = true;
    allowedTCPPorts = [ 8883 ];
    allowedUDPPorts = [ 2021 ];
  };

  # Set your time zone.
  time.timeZone = "Europe/Berlin";

  # Network
  networking.networkmanager.enable = true;
  networking.networkmanager.unmanaged = [ "p2p-dev-wlp0s20f3" ];
  systemd.services.ModemManager.enable = true;
  systemd.services.NetworkManager-wait-online.enable = false;
  services.printing.enable = true;

  services.avahi.enable = true;
  services.tailscale.enable = true;
  services.blueman.enable = true;
  services.power-profiles-daemon.enable = true;

  # TODO: delete this later
  system.stateVersion = "23.05"; # Did you read the comment?
}
