{ lib, config, ... }:

let
  repo = (builtins.fetchGit {
        url = "https://git.finally.coffee/transcaffeine/dotfiles.git";
        ref = "main";
        shallow = true;
  });
  utils = import ../../../utils { inherit lib; };
in {
  programs.gpg = let
    gpgconf = builtins.listToAttrs (
      map (entry: {
          name = toString (lib.sublist 0 1 (lib.splitString " " entry));
          value = toString (lib.sublist 1 100 (lib.splitString " " entry));
      }) (
        builtins.filter (value: value != "") (
          lib.splitString "\n" (
            lib.readFile (repo.outPath + "/config/gnupg/gpg.conf")
          )
        )
      )
    );
  in {
    enable = true;
    settings = gpgconf;
  };
  services.gpg-agent = let
    gpg_agent_config = builtins.listToAttrs (
      map (entry: let
        val = toString (lib.sublist 1 100 (lib.splitString " " entry));
        emptyStringToTrue = (x: if lib.isBool x then x else if x == "" then true else x);
      in {
        name = toString (lib.sublist 0 1 (lib.splitString " " entry));
        value = emptyStringToTrue val;
      }) (
        builtins.filter (v: v != "") (
          lib.splitString "\n" (
            lib.readFile (repo.outPath + "/config/gnupg/gpg-agent.conf")
          )
        )
      )
    );
  in {
    enable = true;
    enableSshSupport = gpg_agent_config."enable-ssh-support";
    defaultCacheTtl = gpg_agent_config."default-cache-ttl" or 300;
    maxCacheTtl = gpg_agent_config."max-cache-ttl" or 900;
    defaultCacheTtlSsh = gpg_agent_config."default-cache-ttl-ssh" or 300;
    maxCacheTtlSsh = gpg_agent_config."max-cache-ttl-ssh" or 900;
    extraConfig = utils.attrsToConfig {
      "ignore-cache-for-signing" = gpg_agent_config."ignore-cache-for-signing";
      "no-allow-external-cache" = gpg_agent_config."no-allow-external-cache";
    };
  };

  home.file."${config.programs.gpg.homedir}/gpg.conf".enable = false;
  home.file."${config.programs.gpg.homedir}/gpg-agent.conf".enable = false;
}
